@@ -4,13 +4,13 @@ Download
 """
 
 import logging
-import tempfile
 import warnings
 
 import fsspec
 import pooch
 
 
+logger = logging.getLogger("fetch_data")
 warnings.filterwarnings("ignore", category=RuntimeWarning)
 
 
@@ -25,6 +25,7 @@ def download(
     log_name="_downloads.log",
     decompress=True,
     create_readme=True,
+    readme_name="README.md",
     **kwargs,
 ):
     """Core function to fetch data from a url with a wildcard or as a list.
@@ -65,6 +66,8 @@ def download(
             See the logging module for more information.
         log_name (str): the file name to which logging will be saved. The file is stored
             relative to :code:`dest`. Logging level can be set with the :code:`verbose` arg.
+        create_readme (bool): will create a readme in the destination folder
+        readme_name (str): default readme file name. can change the path relative to dest
         kwargs (key=value): are keyword replacements for any values set in the
             url (if url is no a list) and dest strings
 
@@ -91,7 +94,7 @@ def download(
         logging_level = verbose
     else:
         raise TypeError("verbose must be bool or intiger")
-    logging.getLogger().setLevel(logging_level)
+    logging.getLogger("fetch_data").setLevel(logging_level)
     # Setting the logging file name and storing to kwargs for readme
     log_fname = f"{dest}/{log_name}"
     if logging_level < 40:
@@ -100,7 +103,7 @@ def download(
 
     # creating the readme before downloading
     if create_readme:
-        create_download_readme(**kwargs)
+        create_download_readme(readme_name, **kwargs)
 
     # caching ignored if input is a list
     if isinstance(url, (list, tuple)):
@@ -117,12 +120,12 @@ def download(
         # will simply use url as is
         urls = [url.format_map(kwargs)]
 
-    logging.log(
+    logger.log(
         20, f"{len(urls): >3} files at {commong_substring(urls).format_map(kwargs)}"
     )
     if len(urls) == 0:
         return []
-    logging.log(20, f"Files will be saved to {dest}")
+    logger.log(20, f"Files will be saved to {dest}")
 
     flist = download_urls(
         urls,
@@ -178,9 +181,7 @@ def get_url_list(
         if cache_path.is_file():
             with open(cache_path, "r") as file:
                 flist = file.read().split("\n")
-            logging.log(
-                15, f"Fetched {len(flist)} files from flist cache: {cache_path}"
-            )
+            logger.log(15, f"Fetched {len(flist)} files from flist cache: {cache_path}")
             return sorted(flist)
 
     purl = urlparse(url)
@@ -188,7 +189,7 @@ def get_url_list(
     host = purl.netloc
     path = purl.path
 
-    logging.log(15, f"Fetching filenames from {url}")
+    logger.log(15, f"Fetching filenames from {url}")
 
     props = {"protocol": protocol}
     if not protocol.startswith("http"):
@@ -220,7 +221,7 @@ def get_url_list(
         with open(cache_path, "w") as out_file:
             out_file.write("\n".join(flist))
 
-    logging.log(15, f"Cached {len(flist)} urls to: {cache_path}")
+    logger.log(15, f"Cached {len(flist)} urls to: {cache_path}")
     logging.debug(flist)
 
     return sorted(flist)
@@ -278,7 +279,7 @@ def download_urls(
         url = kwargs.get("url")
 
         try:
-            logging.log(15, f"retrieving {url}")
+            logger.log(15, f"retrieving {url}")
             return 0, pooch.retrieve(**kwargs)
         except KeyboardInterrupt as e:
             raise (e)
@@ -296,14 +297,14 @@ def download_urls(
         except Exception as e:
             if "550" in str(e):
                 message = f"ERROR: Check file permissions: {url}. "
-                logging.log(20, message)
+                logger.log(20, message)
             return 1, url
         finally:
             return 1, url
 
     from pooch import Unzip
 
-    progressbar = (1 // n_jobs) & (logging.getLogger().level <= 20)
+    progressbar = (1 // n_jobs) & (logging.getLogger("fetch_data").level <= 20)
     download_args = []
     for url in urls:
         download_args += (
@@ -405,7 +406,7 @@ def choose_processor(url):
     return chosen
 
 
-def create_download_readme(**entry):
+def create_download_readme(fname, **entry):
     """
     Creates a README file based on the information in the source dictionary.
 
@@ -425,7 +426,7 @@ def create_download_readme(**entry):
     dest = entry.get("dest")
 
     # readme will always be overwritten
-    readme_fname = posixpath(f"{dest}/README.txt")
+    readme_fname = posixpath(f"{dest}/{fname}")
 
     readme_fname.parent.mkdir(parents=True, exist_ok=True)
 
@@ -434,7 +435,10 @@ def create_download_readme(**entry):
         url = commong_substring(url) + "..."
 
     readme_text = make_readme_file(
-        entry.get("name", ""), url, entry.get("meta", {}), short_info_len_limit=len(url)
+        entry.get("name", ""),
+        url,
+        entry.get("meta", {}),
+        short_info_len_limit=max([120, len(url)]),
     )
 
     with open(readme_fname, "w") as file:
